pub struct MongodbSessionStore { /* private fields */ }Expand description
A MongoDB session store.
Implementations
Sourceimpl MongodbSessionStore
impl MongodbSessionStore
Sourcepub async fn new(uri: &str, db_name: &str, coll_name: &str) -> Result<Self>
pub async fn new(uri: &str, db_name: &str, coll_name: &str) -> Result<Self>
Create a new instance of MongodbSessionStore after stablish the connection to monngodb.
let store =
MongodbSessionStore::new("mongodb://127.0.0.1:27017", "db_name", "collection")
.await?;Sourcepub fn from_client(client: Client, db_name: &str, coll_name: &str) -> Self
pub fn from_client(client: Client, db_name: &str, coll_name: &str) -> Self
Create a new instance of MongodbSessionStore from an open client.
use mongodb::{options::ClientOptions, Client};
let client_options = match ClientOptions::parse("mongodb://127.0.0.1:27017").await {
Ok(c) => c,
Err(e) => panic!("Client Options Failed: {}", e),
};
let client = match Client::with_options(client_options) {
Ok(c) => c,
Err(e) => panic!("Client Creation Failed: {}", e),
};
let store = MongodbSessionStore::from_client(client, "db_name", "collection");Sourcepub async fn initialize(&self) -> Result
pub async fn initialize(&self) -> Result
Initialize the default expiration mechanism, based on the document expiration
that mongodb provides https://docs.mongodb.com/manual/tutorial/expire-data/#expire-documents-at-a-specific-clock-time.
The default ttl applyed to sessions without expiry is 20 minutes.
If the expireAt date field contains a date in the past, mongodb considers the document expired and will be deleted.
Note: mongodb runs the expiration logic every 60 seconds.
let store =
MongodbSessionStore::new("mongodb://127.0.0.1:27017", "db_name", "collection")
.await?;
store.initialize().await?;Sourcepub async fn index_on_expiry_at(&self) -> Result
pub async fn index_on_expiry_at(&self) -> Result
Create a new index for the expireAt property, allowing to expire sessions at a specific clock time.
If the expireAt date field contains a date in the past, mongodb considers the document expired and will be deleted.
https://docs.mongodb.com/manual/tutorial/expire-data/#expire-documents-at-a-specific-clock-time
let store =
MongodbSessionStore::new("mongodb://127.0.0.1:27017", "db_name", "collection")
.await?;
store.index_on_expiry_at().await?;Trait Implementations
Sourceimpl Clone for MongodbSessionStore
impl Clone for MongodbSessionStore
Sourcefn clone(&self) -> MongodbSessionStore
fn clone(&self) -> MongodbSessionStore
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MongodbSessionStore
impl Debug for MongodbSessionStore
Sourceimpl SessionStore for MongodbSessionStore
impl SessionStore for MongodbSessionStore
Sourcefn store_session<'life0, 'async_trait>(
&'life0 self,
session: Session,
) -> Pin<Box<dyn Future<Output = Result<Option<String>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn store_session<'life0, 'async_trait>(
&'life0 self,
session: Session,
) -> Pin<Box<dyn Future<Output = Result<Option<String>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourcefn load_session<'life0, 'async_trait>(
&'life0 self,
cookie_value: String,
) -> Pin<Box<dyn Future<Output = Result<Option<Session>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn load_session<'life0, 'async_trait>(
&'life0 self,
cookie_value: String,
) -> Pin<Box<dyn Future<Output = Result<Option<Session>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,